# Simple Messaging Applicatoin

The simple messaging application provides a simple broadcast/directed text based chat application to Faraday. It does not implement any error correction or retry capabilities.

## General Operation


### GET


### POST


## To-Do

* Update with INI file configuration
* Update with GET POST functionallity